@@ -155,8 +155,8 @@ class App:
 
         return wrapper
 
-    def add_middleware(self, middleware_cls, **kwargs):
-        self.middleware.add(middleware_cls, kwargs)
+    def add_middleware(self, middleware_cls, *args):
+        self.middleware.add(middleware_cls, *args)
 
     def to_seconds(self, time: int, type) -> int:
         if type.lower() not in ["hour", "minute"]:
