@@ -1,4 +1,5 @@
 from starlette.requests import Request
+import inspect
 
 
 class Middleware:
@@ -12,10 +13,10 @@ class Middleware:
 
         await response(scope, receive, send)
 
-    def add(self, middleware_cls, **kwargs):
-        if kwargs == {}:
-            kwargs = None
-        self.app = middleware_cls(self.app, **kwargs)
+    def add(self, middleware_cls, *args):
+        if args == []:
+            args = None
+        self.app = middleware_cls(self.app, *args)
 
     async def process_request(self, req):
         pass
@@ -24,9 +25,16 @@ class Middleware:
         pass
 
     async def handle_request(self, request):
-        await self.process_request(request)
+        if inspect.iscoroutinefunction(self.process_request):
+            await self.process_request(request)
+        else:
+            self.process_response(request)
 
         response = await self.app.handle_request(request)
-        await self.process_response(request, response)
+        
+        if inspect.iscoroutinefunction(self.process_response):
+            await self.process_response(request, response)
+        else:
+            self.process_response(request, response)
 
         return response
