@@ -1,4 +1,4 @@
-from starlette.responses import FileResponse, Response
+from starlette.responses import Response
 import os
 import mimetypes
 
